pub struct EarlyCloseRule {
pub rule: HolidayRule,
pub close_time: NaiveTime,
}Expand description
An early-close rule. rule resolves to a date (using the same machinery
as holiday rules); close_time is the local time at which the venue
closes on that date instead of its regular session close.
Fields
rule: HolidayRuleclose_time: NaiveTimeTrait Implementations
Sourceimpl Clone for EarlyCloseRule
impl Clone for EarlyCloseRule
Sourcefn clone(&self) -> EarlyCloseRule
fn clone(&self) -> EarlyCloseRule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for EarlyCloseRule
impl RefUnwindSafe for EarlyCloseRule
impl Send for EarlyCloseRule
impl Sync for EarlyCloseRule
impl Unpin for EarlyCloseRule
impl UnsafeUnpin for EarlyCloseRule
impl UnwindSafe for EarlyCloseRule